@@ -264,11 +264,12 @@ typedef struct {		/* -- FIELD DESCRIPTOR --		*/
 #define DBIcf_TaintOut    0x040000	/* taint outgoing data */
 #define DBIcf_Executed    0x080000	/* do/execute called since commit/rollb */
 #define DBIcf_PrintWarn   0x100000	/* warn() on warning (err="0")		*/
+#define DBIcf_Callbacks   0x200000	/* has Callbacks attribute hash		*/
 /* NOTE: new flags may require clone() to be updated */
 
 #define DBIcf_INHERITMASK		/* what NOT to pass on to children */	\
   (U32)( DBIcf_COMSET | DBIcf_IMPSET | DBIcf_ACTIVE | DBIcf_IADESTROY		\
-  | DBIcf_AutoCommit | DBIcf_BegunWork | DBIcf_Executed )
+  | DBIcf_AutoCommit | DBIcf_BegunWork | DBIcf_Executed | DBIcf_Callbacks )
 
 /* general purpose bit setting and testing macros			*/
 #define DBIbf_is( bitset,flag)		((bitset) &   (flag))
@@ -386,7 +387,7 @@ struct dbistate_st {
 #define DBISTATE_VERSION  94	/* Must change whenever dbistate_t does	*/
 
     /* this must be the first member in structure			*/
-    void (*check_version) _((char *name,
+    void (*check_version) _((const char *name,
 		int dbis_cv, int dbis_cs, int need_dbixs_cv,
 		int drc_s, int dbc_s, int stc_s, int fdc_s));
 
@@ -403,22 +404,22 @@ struct dbistate_st {
     char      * (*neat_svpv)	_((SV *sv, STRLEN maxlen));
     imp_xxh_t * (*getcom)	_((SV *h));	/* see DBIh_COM macro	*/
     void        (*clearcom)	_((imp_xxh_t *imp_xxh));
-    SV        * (*event)	_((SV *h, char *name, SV*, SV*));
+    SV        * (*event)	_((SV *h, const char *name, SV*, SV*));
     int         (*set_attr_k)	_((SV *h, SV *keysv, int dbikey, SV *valuesv));
     SV        * (*get_attr_k)	_((SV *h, SV *keysv, int dbikey));
     AV        * (*get_fbav)	_((imp_sth_t *imp_sth));
-    SV        * (*make_fdsv)	_((SV *sth, char *imp_class, STRLEN imp_size, char *col_name));
+    SV        * (*make_fdsv)	_((SV *sth, const char *imp_class, STRLEN imp_size, const char *col_name));
     int         (*bind_as_num)	_((int sql_type, int p, int s, int *t, void *v));
-    int         (*hash)		_((char *string, long i));
+    int         (*hash)		_((const char *string, long i));
     SV        * (*preparse)	_((SV *sth, char *statement, IV ps_return, IV ps_accept, void *foo));
 
     SV *neatsvpvlen;		/* only show dbgpvlen chars when debugging pv's	*/
 
     PerlInterpreter * thr_owner;	/* thread that owns this dbistate	*/
 
-    int         (*logmsg)	_((imp_xxh_t *imp_xxh, char *fmt, ...));
+    int         (*logmsg)	_((imp_xxh_t *imp_xxh, const char *fmt, ...));
     int         (*set_err_sv)	_((SV *h, imp_xxh_t *imp_xxh, SV   *err, SV   *errstr, SV   *state, SV   *method));
-    int         (*set_err_char) _((SV *h, imp_xxh_t *imp_xxh, char *err, IV err_i, char *errstr, char *state, char *method));
+    int         (*set_err_char) _((SV *h, imp_xxh_t *imp_xxh, const char *err, IV err_i, const char *errstr, const char *state, const char *method));
     int         (*bind_col)     _((SV *sth, SV *col, SV *ref, SV *attribs));
 
     void *pad2[5];
