@@ -38,6 +38,13 @@ $DBI::tfh = Symbol::gensym();
 open $DBI::tfh, ">&STDERR" or warn "Can't dup STDERR: $!";
 select( (select($DBI::tfh), $| = 1)[0] );  # autoflush
 
+# check for weaken support, used by ChildHandles
+my $HAS_WEAKEN = eval { 
+    require Scalar::Util;
+    # this will croak() if this Scalar::Util doesn't have a working weaken().
+    Scalar::Util::weaken(my $test = \"foo"); 
+    1;
+};
 
 %DBI::last_method_except = map { $_=>1 } qw(DESTROY _set_fbav set_err);
 
@@ -143,6 +150,8 @@ my %is_valid_attribute = map {$_ =>1 } (keys %is_flag_attribute, qw(
 	Attribution
 	BegunWork
 	CachedKids
+        Callbacks
+	ChildHandles
 	CursorName
 	Database
 	DebugDispatch
@@ -169,6 +178,7 @@ my %is_valid_attribute = map {$_ =>1 } (keys %is_flag_attribute, qw(
 	SCALE
 	Statement
 	TYPE
+        Type
 	TraceLevel
 	Username
 	Version
@@ -440,6 +450,18 @@ sub _setup_handle {
 	    $h_inner->{Driver} = $parent;
 	}
 	$h_inner->{_parent} = $parent;
+
+	# add to the parent's ChildHandles
+	if ($HAS_WEAKEN) {
+	    my $handles = $parent->{ChildHandles} ||= [];
+	    push @$handles, $h;
+	    Scalar::Util::weaken($handles->[-1]);
+	    # purge destroyed handles occasionally
+	    if (@$handles % 120 == 0) {
+		@$handles = grep { defined } @$handles;
+		Scalar::Util::weaken($_) for @$handles; # re-weaken after grep
+	    }
+	}   
     }
     else {	# setting up a driver handle
         $h_inner->{Warn}		= 1;
@@ -449,6 +471,7 @@ sub _setup_handle {
         $h_inner->{CompatMode}		= (1==0);
 	$h_inner->{FetchHashKeyName}	||= 'NAME';
 	$h_inner->{LongReadLen}		||= 80;
+	$h_inner->{ChildHandles}        ||= [] if $HAS_WEAKEN;
     }
     $h_inner->{"_call_depth"} = 0;
     $h_inner->{ErrCount} = 0;
@@ -645,6 +668,13 @@ sub FETCH {
 	return ($h->FETCH('TaintIn') && $h->FETCH('TaintOut')) if $key eq'Taint';
 	return (1==0) if $is_flag_attribute{$key}; # return perl-style sv_no, not undef
 	return $DBI::dbi_debug if $key eq 'TraceLevel';
+        return [] if $key eq 'ChildHandles';
+        if ($key eq 'Type') {
+            return "dr" if $h->isa('DBI::dr');
+            return "db" if $h->isa('DBI::db');
+            return "st" if $h->isa('DBI::st');
+            Carp::carp( sprintf "Can't get determine Type for %s",$h );
+        }
 	if (!$is_valid_attribute{$key} and $key =~ m/^[A-Z]/) {
 	    local $^W; # hide undef warnings
 	    Carp::carp( sprintf "Can't get %s->{%s}: unrecognised attribute (@{[ %$h ]})",$h,$key )
